@@ -9,31 +9,34 @@ test_that("Check if Athena Request created correctly",{
   skip_if_no_env()
   # Test connection is using AWS CLI to set profile_name 
   con1 <- dbConnect(athena(),
+                    profile_name = "rathena",
                     encryption_option = "SSE_S3",
                     kms_key = "test_key",
                     work_group = "test_group",
                     s3_staging_dir = Sys.getenv("noctua_s3_query"))
   
   con2 <- dbConnect(athena(),
+                    profile_name = "rathena",
                     encryption_option = "SSE_S3",
                     work_group = "test_group",
                     s3_staging_dir = Sys.getenv("noctua_s3_query"))
   
   con3 <- dbConnect(athena(),
+                    profile_name = "rathena",
+                    work_group = "test_group",
+                    s3_staging_dir = Sys.getenv("noctua_s3_query"))
+  
+  con4 <- dbConnect(athena(),
+                    profile_name = "rathena",
                     s3_staging_dir = Sys.getenv("noctua_s3_query"))
   
   R1 <- noctua:::ResultConfiguration(con1)
   R2 <- noctua:::ResultConfiguration(con2)
   R3 <- noctua:::ResultConfiguration(con3)
+  R4 <- noctua:::ResultConfiguration(con4)
 
   expect_equal(R1, athena_test_req1)
   expect_equal(R2, athena_test_req2)
   expect_equal(R3, athena_test_req3)
-  
-  # clean up system environmental variables
-  Sys.unsetenv("AWS_ACCESS_KEY_ID")
-  Sys.unsetenv("AWS_SECRET_ACCESS_KEY")
-  Sys.unsetenv("AWS_SESSION_TOKEN")
-  Sys.unsetenv("AWS_PROFILE")
-  Sys.unsetenv("AWS_REGION")
+  expect_equal(R4, athena_test_req4)
 })
\ No newline at end of file
